### Marta Shocket, Indiana University, Stanford University
### Code for 'Parasite rearing and infection temperatures jointly influence disease 
### transmission and shape seasonality of epidemics. Published in Ecology.(2018)

### Purpose: 1) to calculate transmission rate (beta) and infectivity (u) for each temperature treatment
#            2) to fit infectivity (u) as linear model of rearing and current infection temperatures
#            3) to bootstrap calculations for beta and u

### Table of Contents:
#      1. Set Working Directory, Load Libraries and Data
#      2. Fit beta values from infection prevalence data
#      3. Calculate u values from betas and foraging rates
#      4. Boostrap betas for each temperature treatment
#      5. Bootstrap u plane coefficients
#      6. Figure 2 Panels C and D


######
##### 1. Set Working Directory, Load Libraries, Get Data
######

# Set working directory
setwd("~/Dropbox/Research Hall Lab/Temperature/Temp Spore Infectivity")

## Load libraries
library(bbmle)
library(scatterplot3d)

# Load infection data
inf.data <- read.csv("TempDepInfectionAssayData.csv")


######
##### 2. Fit beta values from infection prevalence data
######

# Subset by rearing (past) and infection (current) temperatures
  # for each temp treatment, subset, then run mle2() function below, pull coef, then repeat
inf.data.sub <- subset(inf.data, Past == 15 & Current == 15)
inf.data.sub <- subset(inf.data, Past == 15 & Current == 18)
inf.data.sub <- subset(inf.data, Past == 15 & Current == 20)
inf.data.sub <- subset(inf.data, Past == 15 & Current == 22)
inf.data.sub <- subset(inf.data, Past == 15 & Current == 25)
inf.data.sub <- subset(inf.data, Past == 18 & Current == 15)
inf.data.sub <- subset(inf.data, Past == 18 & Current == 18)
inf.data.sub <- subset(inf.data, Past == 18 & Current == 20)
inf.data.sub <- subset(inf.data, Past == 18 & Current == 22)
inf.data.sub <- subset(inf.data, Past == 18 & Current == 25)
inf.data.sub <- subset(inf.data, Past == 20 & Current == 15)
inf.data.sub <- subset(inf.data, Past == 20 & Current == 18)
inf.data.sub <- subset(inf.data, Past == 20 & Current == 20)
inf.data.sub <- subset(inf.data, Past == 20 & Current == 22)
inf.data.sub <- subset(inf.data, Past == 20 & Current == 25)
inf.data.sub <- subset(inf.data, Past == 22 & Current == 15)
inf.data.sub <- subset(inf.data, Past == 22 & Current == 18)
inf.data.sub <- subset(inf.data, Past == 22 & Current == 20)
inf.data.sub <- subset(inf.data, Past == 22 & Current == 22)
inf.data.sub <- subset(inf.data, Past == 22 & Current == 25)

# Calculate best fit for beta
beta.calc <- mle2(NumUninf ~ dbinom(size=Num, prob=exp(-Beta*10000*1)), start=list(Beta = 0.0001), 
                 control=list(parscale = c(Beta = 0.0001)), data = inf.data.sub)
summary(beta.calc)

# Get beta coef
coef(beta.calc)


######
##### 3. Calculate u values from betas and foraging rates
######

# Get data of proportions infected
pcb.data = read.csv("PastTempCurrentTempBetas.csv")

# Calculate u by dividing beta by feeding rates: beta / f = u
# f is for body size = 1.5 mm (large adults used in the infection assay)
past.temps <- c(288.15, 291.15, 293.15, 295.15)
current.temps <- c(288.15, 291.15, 293.15, 295.15, 298.15)
f.rates <- 1.5^2.15*0.00539*exp(0.874*10000*(1/293.15 - 1/current.temps))

# Repeat so it can be added to data frame as a column
f.rates.repeat <- c(f.rates[1], f.rates[1], f.rates[1], f.rates[1], f.rates[2], f.rates[2], f.rates[2], f.rates[2], 
                   f.rates[3], f.rates[3], f.rates[3], f.rates[3], f.rates[4], f.rates[4], f.rates[4], f.rates[4], 
                   f.rates[5], f.rates[5], f.rates[5], f.rates[5])
pcb.data$f.rate <- c(f.rates.repeat)

# Calculate u
pcb.data$u <- c(pcb.data$beta/f.rates.repeat)

# Fit linear model for u as a function of Rearing and Exposure/Infection temperature
u.lm <- lm(pcb.data$u ~ (pcb.data$CurrentArr) + (pcb.data$PastArr))
summary(u.lm)

# Save coefficients from linear model for u
u.int.coef = coef(u.lm)[1]
u.past.coef = coef(u.lm)[3]
u.pres.coef = coef(u.lm)[2]

# Make u predictions from model
pcb.data$u.pred = c(u.int.coef + u.past.coef*pcb.data$PastArr + u.pres.coef*pcb.data$CurrentArr)

# Make beta predictions from model
pcb.data$beta.pred = c(pcb.data$u.pred*pcb.data$f.rate)

save(pcb.data, file = "pcb.data.Rsave")


######
##### 4. Bootstrap betas for each temperature treatment
######

################## Function - BootstrapFactorialBetas 

# Arguments: 
  # data.set          (data frame: subset of infection assay data)
  # kIterations       (integer: number of bootstraping iterations = number of coefficient sets produced)
# Returns: 
  # function.coefs    (data frame: bootstrapped fit coefficients)

BootstrapFactorialBetas = function(data.set, kIterations) {
  
  ######## Prep Work
  
  # Create data frame to store list of betas
  beta.storage = data.frame(P15.C15 = numeric(kIterations), P15.C18 = numeric(kIterations), P15.C20 = numeric(kIterations), P15.C22 = numeric(kIterations), P15.C25 = numeric(kIterations),
                            P18.C15 = numeric(kIterations), P18.C18 = numeric(kIterations), P18.C20 = numeric(kIterations), P18.C22 = numeric(kIterations), P18.C25 = numeric(kIterations),
                            P20.C15 = numeric(kIterations), P20.C18 = numeric(kIterations), P20.C20 = numeric(kIterations), P20.C22 = numeric(kIterations), P20.C25 = numeric(kIterations),
                            P22.C15 = numeric(kIterations), P22.C18 = numeric(kIterations), P22.C20 = numeric(kIterations), P22.C22 = numeric(kIterations), P22.C25 = numeric(kIterations))
  # Create vector of past temps
  past.temps <- c(15, 18, 20, 22) 
  
  # Create vector of current temps
  current.temps <- c(15, 18, 20, 22, 25)
  
  # Create counter for beta.storage column
  counter = 0
  
  ######## Bootstrapping
  
  # Loop through past temps
  for (iPast in 1:4) {
    
    # Loop through current temps
    for (iCurrent in 1:5) {
      
      # Subset data by past and current temperature
      data = subset(data.set, Current == current.temps[iCurrent] & Past == past.temps[iPast])
      
      # Increment counter for beta.storage column
      counter = counter + 1
      
      # Loop through bootstrapping iterations
      for (iIteration in 1:kIterations) {
        
        # Create random sample of row numbers
        boot.rows = sample(nrow(data), size = nrow(data), replace = T)
        
        # Create data frame for simulated data set
        simulated.data.set = data[boot.rows[1], ]
        
        # Fill in the rest of the rows
        for (iRow in 2:length(boot.rows)) {
          
          simulated.data.set = rbind(simulated.data.set, data[boot.rows[iRow], ])
          
        }
        
        # Calculate beta of simulated data set
        beta.calc = mle2(NumUninf ~ dbinom(size=Num, prob=exp(-Beta*10000*1)), start=list(Beta = 0.0001), 
                         control=list(parscale = c(Beta = 0.0001)), data = simulated.data.set)
        
        # Store beta parameter; divide by ten to get correct units (L instead of beakers)
        beta.storage[iIteration, counter] = coef(beta.calc)/10
        
      } # Bootstrapping iteration loop
      
    } # Current temp loop
    
  } # Past temp  loop
  
  beta.storage # return bootstrapped betas
  
}

################## Function - bstrap.CIs.20

bstrap.CIs.20 = function(dataframe) {
  
  # create output datafame
  output = data.frame(Upper = numeric(20), Lower = numeric(20), row.names = c("P15.C15", "P15.C18", "P15.C20", "P15.C22", "P15.C25", 
                                                                              "P18.C15", "P18.C18", "P18.C20", "P18.C22", "P18.C25", 
                                                                              "P20.C15", "P20.C18", "P20.C20", "P20.C22", "P20.C25", 
                                                                              "P22.C15", "P22.C18", "P22.C20", "P22.C22", "P22.C25"))
  # Loop through columns of bootstrapped beta data
  for (iCol in 1:20) {
    
    output[iCol, 1] = quantile(dataframe[ , iCol], probs = c(0.975))
    output[iCol, 2] = quantile(dataframe[ , iCol], probs = c(0.025))
    
  }
  
  output
}


# Bootstrap betas
bstrapbetas = BootstrapFactorialBetas(trans.data, 8000)
write.csv(bootall, "bstrapbetas10000.csv")

# Calculate CIs
bstrapCIs = bstrap.CIs(bootall)
write.csv(bstrapCIs, "bstrapbetasCIs.csv")


######
##### 5. Bootstrap u plane coefficients
######

# Read in bootstrapped data - remove the extra column of row numbers
bs.betas <- read.csv("bstrapbetas10000.csv")[, -1]
bs.fr <- read.csv("fr_MLE_points.csv")[, -1]

# Create empty data frame for u data
u.calc <- data.frame(matrix(ncol = 20, nrow = 10000))
col.names <- colnames(bs.betas)
colnames(u.calc) <- col.names

# Create dataframe with repeated forating rate data to match beta data
bs.fr.rep <- cbind(bs.fr, bs.fr, bs.fr, bs.fr)

# Calculate boostrapped u from bootstrapped beta / bootstrapped f
u.calc <- bs.betas / bs.fr.rep

# Create empty data frame for plane coefficients
plane.coefs <- data.frame(Intercept = numeric(10000), CurrentSlope = numeric(10000), PastSlope = numeric(10000))

# Create vectors of past and current temps to use in the data frame
past.temps <- c(288.15, 288.15, 288.15, 288.15, 288.15, 291.15, 291.15, 291.15, 291.15, 291.15, 
                293.15, 293.15, 293.15, 293.15, 293.15, 295.15, 295.15, 295.15, 295.15, 295.15)
current.temps <- c(288.15, 291.15, 293.15, 295.15, 298.15, 288.15, 291.15, 293.15, 295.15, 298.15, 
                   288.15, 291.15, 293.15, 295.15, 298.15, 288.15, 291.15, 293.15, 295.15, 298.15)

# Loop through reps
for (i in 1:10000){
  
  # Select row i from the u.calc data and put in a data frame (as a column) with the past and current temps
  boot.dataset <- data.frame(PastTemp = past.temps, CurrentTemp = current.temps, u = as.numeric(u.calc[i, ]))
  
  # Fit lm
  u.lm <- lm(boot.dataset$u*10000 ~ boot.dataset$CurrentTemp + boot.dataset$PastTemp)
  
  # Save lm coefficients
  plane.coefs[i, 1] <- coef(u.lm)[1]
  plane.coefs[i, 2] <- coef(u.lm)[2]
  plane.coefs[i, 3] <- coef(u.lm)[3]
  
}

# save output
write.csv(plane.coefs, "BootstrappedPlaneCoefficients.csv")

# Calculate 95% CIs
quantile(plane.coefs$Intercept, probs = c(0.025, 0.975))
quantile(plane.coefs$CurrentSlope, probs = c(0.025, 0.975))
quantile(plane.coefs$PastSlope, probs = c(0.025, 0.975))


######
##### 7. Figure 2 Panels C and D
######

load("pcb.data.Rsave")

# Re-sort the data frame by rearing temperature for plotting
pcb.data.resort <- pcb.data[order(pcb.data$Past.Temp), ]

par(mfrow = c(1,1),  mgp = c(3, 1, 0), mar = c(5, 5, 1, 1), oma = c(0,0,0,0), las = 1)

######### Figure 2 Panel C: 3D plot of u

# Attach data (necessary for 3D plot)
attach(pcb.data)

# Color list for plotting
col.list <- c("navy", "royalblue2", "salmon2", "red3",
              "navy", "royalblue2", "salmon2", "red3",
              "navy", "royalblue2", "salmon2", "red3",
              "navy", "royalblue2", "salmon2", "red3",
              "navy", "royalblue2", "salmon2", "red3")

# Plotting in Celcius
u.3Dplot = scatterplot3d(CurrentTemp, Past.Temp, u*10000, highlight.3d = F, type = "h", lwd = 2,
                          xlab = expression(paste("Exposure/Infection temperature (",degree,"C)")), xlim = c(15, 25),
                          ylab = "", zlab = "", 
                          zlim = c(0, 14), 
                          y.ticklabs = c(15, "", 17, "", 19, "", 21, ""), pch = 21, bg = col.list,
                          z.ticklabs = c("", 2, "", 6, "", 10, "", 14), box = TRUE, color = col.list,
                          cex.axis = 0.9, cex.lab = 1.05, cex.symbols = 1.25, angle = 55, grid = FALSE)

# Fit linear model (plane) in Celcius, transformed by x10000 for plotting
u.lm <- lm(pcb.data$u*10000 ~ (pcb.data$CurrentTemp) + (pcb.data$Past.Temp))
u.3Dplot$plane3d(u.lm, lty.box = "solid", col = "grey35", lty = "dotted")
u.3Dplot$plane3d(u.lm, lty.box = "solid", col = "black", lty = "blank")

######### Figure 2 Panel D: transmission rate (beta)
par(mfrow = c(1,1), mar = c(5, 5, 1, 1), oma = c(0,0,0,0), las = 1)

diag.data <- rbind(pcb.data[1, ], pcb.data[6, ], pcb.data[11, ], pcb.data[16, ], pcb.data[20, ])

plot(beta*100000 ~ CurrentTemp, data = diag.data, ylim = c(0.1, 2.1), 
     col = "black", lwd = 1.2, cex.axis = 1, cex.lab = 1.25, ylab = expression(paste("Transmission rate - ",beta," (L spore"^-1,"day"^-1," 10"^-5,")")),
     xlab = expression(paste("Exposure/Infection temperature - ",italic("T"[EI])," (",degree,"C)")), type = "p", pch = 21, bg = "white", cex = 2.25, lty = 2)
lines(beta*100000 ~ CurrentTemp, data = pcb.data.resort[1:5, ], col = "midnightblue", lwd = 2, bg = "midnightblue", type = "o", pch = 21, cex = 1.1, lty = 2)
lines(beta*100000 ~ CurrentTemp, data = pcb.data.resort[6:10, ], col = "royalblue2", lwd = 2, bg = "royalblue2", type = "o", pch = 21, cex = 1.1, lty = 2)
lines(beta*100000 ~ CurrentTemp, data = pcb.data.resort[11:15, ], col = "salmon2", lwd = 2, bg = "salmon2", type = "o", pch = 21, cex = 1.1, lty = 2)
lines(beta*100000 ~ CurrentTemp, data = pcb.data.resort[16:20, ], col = "red3", lwd = 2, bg = "red3", type = "o", pch = 21, cex = 1.1, lty = 2)

lines(beta.pred*100000 ~ CurrentTemp, data = pcb.data.resort[1:5, ], col = "midnightblue", lty = 1, lwd = 2)
lines(beta.pred*100000 ~ CurrentTemp, data = pcb.data.resort[6:10, ], col = "royalblue2", lty = 1, lwd = 2)
lines(beta.pred*100000 ~ CurrentTemp, data = pcb.data.resort[11:15, ], col = "salmon2", lty = 1, lwd = 2)
lines(beta.pred*100000 ~ CurrentTemp, data = pcb.data.resort[16:20, ], col = "red3", lty = 1, lwd = 2)

text(x = 16.5, y = 0.35, labels = expression(paste(italic(T[R])," = 15",degree,"C")), cex = 1.15, col = "midnightblue")
text(x = 23, y = 0.7, labels = expression(paste(italic(T[R])," = 18",degree,"C")), cex = 1.15, col = "royalblue3")
text(x = 23.5, y = 1.1, labels = expression(paste(italic(T[R])," = 20",degree,"C")), cex = 1.15, col = "salmon3")
text(x = 22.5, y = 2, labels = expression(paste(italic(T[R])," = 22",degree,"C")), cex = 1.15, col = "red3")

legend("topleft", legend = "D", bty = "n", cex = 1.25, adj = 1)

######### Figure S1: transmission rate (beta) with error bars

# Read in bootstrapped datas - remove the extra column of row numbers
bs.betas <- read.csv("bstrapbetas10000.csv")[, -1]

# Jitter current temperatures for plotting so CIs aren't on top of each other
jitter.vec <- c(0, -0.2, 0.1, -0.1, 0, -0.2, 0.1, -0.1, 0, -0.2, 0.1, -0.1, 0, -0.2, 0.1, -0.1, 0, -0.2, 0.1, -0.1)
pcb.data.resort$CurrentTempJitter <- pcb.data.resort$CurrentTemp + jitter.vec

# Make data frame for calculating CIs
betaCIs <- data.frame(matrix(ncol = 20, nrow = 2))
colnames(betaCIs) = colnames(bs.betas)

# Calculate CIs
for (i in 1:ncol(betaCIs)){
  betaCIs[1, i] <- quantile(bs.betas[ ,i], 0.025)
  betaCIs[2, i] <- quantile(bs.betas[ ,i], 0.975)
}

# Figure S1
par(mfrow = c(1,1), oma = c(0, 0, 0, 0), mar = c(5, 5, 1, 1))
plot(beta*100000 ~ CurrentTempJitter, data = pcb.data.resort[1:5, ], type = "o", ylim = c(0, 3), col = "midnightblue", pch = 16, main = "", lwd = 2, cex.lab = 1.25, cex= 1.25, 
     xlab = expression(paste("Exposure/infection temperature - ",italic("T"[EI])," (",degree,"C)")), ylab = expression(paste("Transmission rate - ",beta," (L spore"^-1,"day"^-1," 10"^-5,")")), lty = 2)
lines(beta*100000 ~ CurrentTempJitter, data = pcb.data.resort[6:10, ], type = "o", pch = 16, col = "royalblue2", lwd = 2, cex = 1.25, lty = 2)
lines(beta*100000 ~ CurrentTempJitter, data = pcb.data.resort[11:15, ], type = "o", pch = 16, col = "tomato", lwd = 2, cex = 1.25, lty = 2)
lines(beta*100000 ~ CurrentTempJitter, data = pcb.data.resort[16:20, ], type = "o", pch = 16, col = "red4", lwd = 2, cex = 1.25, lty = 2)

# TP = 15
arrows(pcb.data.resort$CurrentTempJitter[1], betaCIs[1, 1]*100000, pcb.data.resort$CurrentTempJitter[1], betaCIs[2, 1]*100000, length = 0, angle = 90, code = 3, lwd = 2, col = "midnightblue")
arrows(pcb.data.resort$CurrentTempJitter[2], betaCIs[1, 2]*100000, pcb.data.resort$CurrentTempJitter[2], betaCIs[2, 2]*100000, length = 0, angle = 90, code = 3, lwd = 2, col = "midnightblue")
arrows(pcb.data.resort$CurrentTempJitter[3], betaCIs[1, 3]*100000, pcb.data.resort$CurrentTempJitter[3], betaCIs[2, 3]*100000, length = 0, angle = 90, code = 3, lwd = 2, col = "midnightblue")
arrows(pcb.data.resort$CurrentTempJitter[4], betaCIs[1, 4]*100000, pcb.data.resort$CurrentTempJitter[4], betaCIs[2, 4]*100000, length = 0, angle = 90, code = 3, lwd = 2, col = "midnightblue")
arrows(pcb.data.resort$CurrentTempJitter[5], betaCIs[1, 5]*100000, pcb.data.resort$CurrentTempJitter[5], betaCIs[2, 5]*100000, length = 0, angle = 90, code = 3, lwd = 2, col = "midnightblue")

# TP = 18
arrows(pcb.data.resort$CurrentTempJitter[6], betaCIs[1, 6]*100000, pcb.data.resort$CurrentTempJitter[6], betaCIs[2, 6]*100000, length = 0, angle = 90, code = 3, lwd = 2, col = "royalblue2")
arrows(pcb.data.resort$CurrentTempJitter[7], betaCIs[1, 7]*100000, pcb.data.resort$CurrentTempJitter[7], betaCIs[2, 7]*100000, length = 0, angle = 90, code = 3, lwd = 2, col = "royalblue2")
arrows(pcb.data.resort$CurrentTempJitter[8], betaCIs[1, 8]*100000, pcb.data.resort$CurrentTempJitter[8], betaCIs[2, 8]*100000, length = 0, angle = 90, code = 3, lwd = 2, col = "royalblue2")
arrows(pcb.data.resort$CurrentTempJitter[9], betaCIs[1, 9]*100000, pcb.data.resort$CurrentTempJitter[9], betaCIs[2, 9]*100000, length = 0, angle = 90, code = 3, lwd = 2, col = "royalblue2")
arrows(pcb.data.resort$CurrentTempJitter[10], betaCIs[1, 10]*100000, pcb.data.resort$CurrentTempJitter[10], betaCIs[2, 10]*100000, length = 0, angle = 90, code = 3, lwd = 2, col = "royalblue2")

# TP = 20
arrows(pcb.data.resort$CurrentTempJitter[11], betaCIs[1, 11]*100000, pcb.data.resort$CurrentTempJitter[11], betaCIs[2, 11]*100000, length = 0, angle = 90, code = 3, lwd = 2, col = "salmon2")
arrows(pcb.data.resort$CurrentTempJitter[12], betaCIs[1, 12]*100000, pcb.data.resort$CurrentTempJitter[12], betaCIs[2, 12]*100000, length = 0, angle = 90, code = 3, lwd = 2, col = "salmon2")
arrows(pcb.data.resort$CurrentTempJitter[13], betaCIs[1, 13]*100000, pcb.data.resort$CurrentTempJitter[13], betaCIs[2, 13]*100000, length = 0, angle = 90, code = 3, lwd = 2, col = "salmon2")
arrows(pcb.data.resort$CurrentTempJitter[14], betaCIs[1, 14]*100000, pcb.data.resort$CurrentTempJitter[14], betaCIs[2, 14]*100000, length = 0, angle = 90, code = 3, lwd = 2, col = "salmon2")
arrows(pcb.data.resort$CurrentTempJitter[15], betaCIs[1, 15]*100000, pcb.data.resort$CurrentTempJitter[15], betaCIs[2, 15]*100000, length = 0, angle = 90, code = 3, lwd = 2, col = "salmon2")

# TP = 22
arrows(pcb.data.resort$CurrentTempJitter[16], betaCIs[1, 16]*100000, pcb.data.resort$CurrentTempJitter[16], betaCIs[2, 16]*100000, length = 0, angle = 90, code = 3, lwd = 2, col = "red3")
arrows(pcb.data.resort$CurrentTempJitter[17], betaCIs[1, 17]*100000, pcb.data.resort$CurrentTempJitter[17], betaCIs[2, 17]*100000, length = 0, angle = 90, code = 3, lwd = 2, col = "red3")
arrows(pcb.data.resort$CurrentTempJitter[18], betaCIs[1, 18]*100000, pcb.data.resort$CurrentTempJitter[18], betaCIs[2, 18]*100000, length = 0, angle = 90, code = 3, lwd = 2, col = "red3")
arrows(pcb.data.resort$CurrentTempJitter[19], betaCIs[1, 19]*100000, pcb.data.resort$CurrentTempJitter[19], betaCIs[2, 19]*100000, length = 0, angle = 90, code = 3, lwd = 2, col = "red3")
arrows(pcb.data.resort$CurrentTempJitter[20], betaCIs[1, 20]*100000, pcb.data.resort$CurrentTempJitter[20], betaCIs[2, 20]*100000, length = 0, angle = 90, code = 3, lwd = 2, col = "red3")

text(x = 23.5, y = 0.3, labels = expression(paste(italic(T[R])," = 15",degree,"C")), cex = 1.15, col = "midnightblue")
text(x = 23.5, y = 0.7, labels = expression(paste(italic(T[R])," = 18",degree,"C")), cex = 1.15, col = "royalblue2")
text(x = 23.5, y = 1.1, labels = expression(paste(italic(T[R])," = 20",degree,"C")), cex = 1.15, col = "salmon3")
text(x = 23.5, y = 2.2, labels = expression(paste(italic(T[R])," = 22",degree,"C")), cex = 1.15, col = "red4")