### Marta Shocket mshocket@stanford.edu
### Code for 'Parasite rearing and infection temperatures jointly influence disease 
### transmission and shape seasonality of epidemics. Published in Ecology.(2018)

### Purpose: to fit (and bootstrap) a function for foraging rate as an Arrhenius function of temperature and a power function of body size

### **** NOTE: TEMPERATURE MUST BE IN KELVIN FOR AN ARRHENIUS FUNCTION TO FIT CORRECTLY (zero is non-arbitrary) ****

### Table of Contents:
#      1. Set Working Directory, Load Libraries and Data
#      2. Functions for Bootstrapping Foraging Rate as a function of temperature
#      3. Console input for Bootstrapping Foraging Rate as a function of temperature
#      4. Calculate foraging rate at Infection Assay Temperatures
#      5. Calculate foraging rate across a temperature gradient
#      6. Figure 2 panels A and B

######
##### 1. Set Working Directory, Load Libraries and Data
######

# Set working directory
setwd("~/Dropbox/Research Hall Lab/Temperature/Temp Spore Infectivity/Final Code and Data")

# Load library for MLE
library(bbmle)

# Read in the foraging rate assay data
fr.assay.data = read.csv("TempDep Foraging Rate Assay Data.csv")


#####
#### 2. Functions for bootstrapping foraging rate as a function of temperature
#####

################## Main Function - BootstrapArrFRMain 

# Arguments: 
  # nBoots      integer: number of bootstraping iterations = number of coefficient sets produced
# Returns: 
  # fx.coefs    data frame: bootstrapped function coefficients

BootstrapArrFRMain = function(nBoots) {
  
  # Create output data frame to record function coefficients
  fx.coefs = data.frame(Iteration = 1:nBoots, n = numeric(nBoots), fref = numeric(nBoots), 
                        TA = numeric(nBoots), sd = numeric(nBoots))
  
  # Start for loop of bootstrapping interations
  for (iBoot in 1:nBoots) { 
    
    # Fit a set of function coefficients
    simulated.data.set = SimulateFRDataSet()
    
    # Fit a set of function coefficients
    fx.coefs = FitFRFunctionCoefs(simulated.data.set, fx.coefs, iBoot)
    
  } # Close for loop of bootstrapping iterations
  
  fx.coefs #Return
  
} # Close main function


################## Component Function - SimulateFRDataSet 

# Arguments:               (none)
# Returns: 
  # simulated.data.set     data frame: bootstrapped foraging rate data set

# Create simulated data set from a treatment data pool
SimulateFRDataSet = function() {
  
  # Subset 15 Degree Treatment first
  subset.fr.data = subset(fr.assay.data, Treatment == "15")
  
  # Create a sample of random row numbers
  boot.rows = sample(nrow(subset.fr.data), size=nrow(subset.fr.data), replace=T)
  
  # Create a data frame and fill it with the first animal from random sample of row numbers
  simulated.data.set = subset.fr.data[boot.rows[1], ]
  
  #Finish filling in the data frame with the rest of the animals from random sample of row numbers
  for (iRow in 2:length(boot.rows)){
    
    simulated.data.set = rbind(simulated.data.set, subset.fr.data[boot.rows[iRow], ])
    
  }
  
  # Now loop through the other temperature treatments
  for (iTreat in c(18, 21, 24, 27)) {
    
    # Subset Treatment
    subset.fr.data = subset(fr.assay.data, Treatment == iTreat)
    
    # Create a sample of random row numbers
    boot.rows = sample(nrow(subset.fr.data), size=nrow(subset.fr.data), replace=T)
    
    # Add rows to data frame
    for (iRow in 1:length(boot.rows)){
      
      simulated.data.set = rbind(simulated.data.set, subset.fr.data[boot.rows[iRow], ])
      
    }
    
  }
  
  simulated.data.set # Return
  
}

################## Component Function - FitFRFunctionCoefs 

# Arguments:
  # data.set     data frame: bootstrapped foraging rate data set
  # fx.coefs     data frame: bootstrapped function coefficients
  # iBoot        integer: # of bootstrapping iterations
# Returns: 
  # fx.coefs     data frame: bootstrapped function coefficients


# Fit a set of function coefficients
FitFRFunctionCoefs = function(data.set, fx.coefs, iBoot) {
  
  # Fit a set of treatment-dependent function coefficients from the set of simulated data for all treatments
  fr.fit = mle2(f ~ dnorm(mean = Size^n * fref * exp(10000*TA*(1/293.15-1/ArrTemp)), sd = sd), 
                start=list(n = 1.5, fref = .005, TA = .8, sd = 0.1), data = data.set)
  
  # Extract and save the fit function coefficients in the main output matrix
  fx.coefs[iBoot,2] = coef(fr.fit)[1] # n
  fx.coefs[iBoot,3] = coef(fr.fit)[2] # fref
  fx.coefs[iBoot,4] = coef(fr.fit)[3] # TA
  fx.coefs[iBoot,5] = coef(fr.fit)[4] # sd
  
  fx.coefs # Return
  
}


#####
#### 3. Console input code for bootstrapping foraging rate as a function of temperature
#####

# Fit best parameters for size/Arrhenius function of foraging rate to data
fr.fit = mle2(f ~ dnorm(mean = Size^n * fref * exp(10000*TA*(1/293.15-1/ArrTemp)), sd = sd), 
              start=list(n = 1.5, fref = .005, TA = .8, sd = 0.1), data = fr.assay.data)
summary(fr.fit)
save(fr.fit, file = "fr.fit.Rsave")

# Bootstrap 10000 parameters for size/Arrhenius function of foraging rate
fr.coefs = BootstrapArrFRMain(10000)

# Export to csv file
write.csv(fr.coefs, "fr_MLE_coefs.csv")

# Calculate CIs for and look at histograms of the coefficients
quantile(fr.coefs$n, c(0.025,0.975))
quantile(fr.coefs$fref, c(0.025,0.975))
quantile(fr.coefs$TA, c(0.025,0.975))

hist(fr.coefs$fref)
hist(fr.coefs$n)
hist(fr.coefs$TA)


######
##### 4. Calculate foraging rate at Infection Assay Temperatures
######

fr.coefs <- read.csv("fr_MLE_coefs.csv")

################## Function to calculate foraging rate
CalcFR = function(arrTemp, size, n, fref, TA) {
  fr <- size^n * fref * exp(10000*TA*(1/293.15-1/arrTemp))
  fr # return value
}

################## Function to calculate FR from bootstrapped function parameters
CalcBSFR = function(arrtemps, size, fr.coefs) {
  
  # Create output data frame
  fr.df <- data.frame(fr15 = numeric(nrow(fr.coefs)), fr18 = numeric(nrow(fr.coefs)), 
                      fr20 = numeric(nrow(fr.coefs)), fr22 = numeric(nrow(fr.coefs)),
                      fr25 = numeric(nrow(fr.coefs)))
  
  # Loop through bootstraps
  for (i in 1:nrow(fr.coefs)) {
    
    # pull out coefs from one bootstrap iteration
    n <- fr.coefs$n[i]
    fref <- fr.coefs$fref[i]
    TA <- fr.coefs$TA[i]
    
    # loop through arrtemps
    for (j in 1:length(IA.arrtemps)) {
      
      # Calculate foraging rate for each temp with parameters for that bootstrap
      fr.df[i, j] <- CalcFR(IA.arrtemps[j], size, n, fref, TA)
      
    } # end loop of temps
    
  } # end loop of bootstrap iteration
  
  fr.df # return output vector
  
} # end function

# List of infection assay temperatures in Kelvin
IA.arrtemps <- c(288.15, 291.15, 293.15, 295.25, 298.15)

# Calculate foragine rate at infection assay temperatures for adult sized Daphnia (1.5 mm) 
FR.bootstrapped <- CalcBSFR(IA.arrtemps, 1.5, fr.coefs)

# Export to csv files
write.csv(FR.bootstrapped, "fr_MLE_points.csv")


######
##### 5. Calculate foraging rate across a temperature gradient
######

# Gradient of temperatures (across x-axis for figure)
grad.temps.C <- seq(15,25,0.25)
grad.temps.K <- grad.arrtemps.C + 273.15

fr.grad.adult <- CalcBSFRGrad(grad.temps.K, 1.5, fr.coefs)
fr.grad.JAavg <- CalcBSFRGrad(grad.temps.K, 0.85, fr.coefs)

# Function to calculate foraging rate across gradient for bootstrapped function coefficients
CalcBSFRGrad = function(arrtemps, size, fr.coefs) {
  
  # Create output data frame
  fr.df <- data.frame(matrix(nrow = nrow(fr.coefs), ncol = length(arrtemps)))
  
  # Loop through bootstraps
  for (i in 1:nrow(fr.coefs)) {
    
    n <- fr.coefs$n[i]
    fref <- fr.coefs$fref[i]
    TA <- fr.coefs$TA[i]
    
    # Calculate foraging rate for each temp along the gradient with parameters for that bootstrap and body size
    fr.df[i, ] <- CalcFR(arrtemps, size, n, fref, TA)
    
  } # end loop of bootstrap iteration
  
  fr.df # return output vector
  
} # end function

########## Calculate fr best estimates and boostrapped quantiles along gradient for plotting

# Create Data frame
fr.grads <- data.frame(TempK = grad.arrtemps.K, TempC = grad.temps.C, adult.calc = numeric(length(grad.temps.K)), JAavg.calc = numeric(length(grad.temps.K)),
                       adult.upperCI = numeric(length(grad.temps.K)), adult.lowerCI = numeric(length(grad.temps.K)),
                       JAavg.upperCI = numeric(length(grad.temps.K)), JAavg.lowerCI = numeric(length(grad.temps.K)))

# Calculate best estimates for both body sizes
fr.grads$adult.calc <- CalcFR(grad.temps.K, 1.5, coef(fr.fit)[1], coef(fr.fit)[2], coef(fr.fit)[3])
fr.grads$JAavg.calc <- CalcFR(grad.temps.K, 0.85, coef(fr.fit)[1], coef(fr.fit)[2], coef(fr.fit)[3])

### Calculate quantiles from bootstrapped foraging rates
# Loop through each temperature
for (i in 1:length(grad.temps.K)) {
  
  # Calculate the quantiles in each column (temp) for all rows (bootstraps)
  fr.grads$adult.upperCI[i] <- quantile(fr.grad.adult[, i], 0.975)
  fr.grads$adult.lowerCI[i] <- quantile(fr.grad.adult[, i], 0.025)
  fr.grads$JAavg.upperCI[i] <- quantile(fr.grad.JAavg[, i], 0.975)
  fr.grads$JAavg.lowerCI[i] <- quantile(fr.grad.JAavg[, i], 0.025)
  
}

save(fr.grads, file = "FRgrads.Rsave")

############# Calculating f across a size gradient and median across temp
# Body size gradient
size.grad <- seq(0.5, 2, 0.05)

# Create data frame to hold calcs
fr.size.grad <- data.frame(f.size.calc.16 = numeric(length(size.grad)), f.size.calc.18 = numeric(length(size.grad)),
                           f.size.calc.21 = numeric(length(size.grad)), f.size.calc.24 = numeric(length(size.grad)),
                           f.size.calc.27 = numeric(length(size.grad)))

# Calculate foraging rate
fr.size.grad$f.size.calc.16 <- CalcFR(289.35, size.grad, coef(fr.fit)[1], coef(fr.fit)[2], coef(fr.fit)[3])
fr.size.grad$f.size.calc.18 <- CalcFR(291.55, size.grad, coef(fr.fit)[1], coef(fr.fit)[2], coef(fr.fit)[3])
fr.size.grad$f.size.calc.21 <- CalcFR(294.05, size.grad, coef(fr.fit)[1], coef(fr.fit)[2], coef(fr.fit)[3])
fr.size.grad$f.size.calc.24 <- CalcFR(296.85, size.grad, coef(fr.fit)[1], coef(fr.fit)[2], coef(fr.fit)[3])
fr.size.grad$f.size.calc.27 <- CalcFR(299.95, size.grad, coef(fr.fit)[1], coef(fr.fit)[2], coef(fr.fit)[3])

save(fr.size.grad, file = "FRsizegrad.Rsave")


#######
##### Figures
######

setwd("~/Dropbox/Research Hall Lab/Temperature/Temp Spore Infectivity")

par(mfrow = c(1, 2), oma = c(3, 0, 0, 4), mar = c(2, 7, 1, 1), las = 1, mgp = c(4.5, 1, 0))

load("FRgrads.Rsave")
load("FRsizegrad.Rsave")
grad.temps.C <- seq(15,25,0.25)
grad.temps.C.rev <- rev(grad.temps.C)
size.grad <- seq(0.5, 2, 0.05)

#####  f as a function of size
f.data.15 = subset(fr.assay.data, Temp == 16.2)
f.data.18 = subset(fr.assay.data, Temp == 18.4)
f.data.21 = subset(fr.assay.data, Temp == 20.9)
f.data.24 = subset(fr.assay.data, Temp == 23.7)
f.data.27 = subset(fr.assay.data, Temp == 26.8)

plot(f ~ Size, xlim = c(0.5, 2), ylim = c(-0.002, 0.065), data = fr.assay.data, 
     ylab = expression(paste("Foraging rate - ",italic("f")," (L/day)")), 
     xlab = "Host body length (mm)", cex.lab = 1.25, cex.axis = 1, col = "White")
points(fr.size.grad$f.size.calc.16 ~ size.grad, type = "l", lty = 1, lwd = 2, col = "black")
points(fr.size.grad$f.size.calc.18 ~ size.grad, type = "l", lty = 5, lwd = 2, col = "black")
points(fr.size.grad$f.size.calc.21 ~ size.grad, type = "l", lty = 2, lwd = 2, col = "black")
points(fr.size.grad$f.size.calc.24 ~ size.grad, type = "l", lty = 4, lwd = 2, col = "black")
points(fr.size.grad$f.size.calc.27 ~ size.grad, type = "l", lty = 3, lwd = 2, col = "black")

points(f ~ Size, data = f.data.27, pch = 22, cex = 1.35, bg = "darkgrey")
points(f ~ Size, data = f.data.24, pch = 21, cex = 1.35, bg = "darkgrey")
points(f ~ Size, data = f.data.21, pch = 24, cex = 1.35, bg = "darkgrey")
points(f ~ Size, data = f.data.18, pch = 3, cex = 1.35)
points(f ~ Size, data = f.data.15, pch = 4, cex = 1.35)

f.a = expression(paste("27 ",degree,"C"))
f.b = expression(paste("24 ",degree,"C"))
f.c = expression(paste("21 ",degree,"C"))
f.d = expression(paste("18 ",degree,"C"))
f.e = expression(paste("16 ",degree,"C"))
legend.txt.f = c(f.a, f.b, f.c, f.d, f.e)
legend(x = 0.65, y = 0.06, legend = legend.txt.f, bty = "n", lty = c(3, 4, 2, 5, 1), pch = c(NA, NA, NA, NA, NA), lwd = 2, cex = 1.1, col = "black", text.col = "white")
legend(x = 0.65, y = 0.06, legend = legend.txt.f, bty = "n", lty = c(0, 0, 0, 0, 0), pch = c(22, 21, 24, 3, 4), pt.bg = "darkgrey", lwd = 1, cex = 1.1, col = "black", bg = NULL, merge = FALSE)

legend("topleft", legend = "A", bty = "n", cex = 1.25, adj = 1)
mtext("Body length (mm)", side = 1, line = 3, las = 1, cex = 1.2)


#### f as a function of Temp

plot(fr.grads$adult.calc ~ grad.temps.C, type = "l", col = "black", lwd = 2, 
     xlab = "", ylab = expression(paste("Foraging rate - ",italic("f")," (L/day)")),
     ylim = c(0, 0.026), cex.axis = 1, cex.lab = 1.25)

#f CI Shading - adult
f.low.rev <- rev(fr.grads$adult.lowerCI)
cord.x <- c(grad.temps.C, grad.temps.C.rev)
f.cord.y <- c(fr.grads$adult.upperCI, f.low.rev)
polygon(cord.x, f.cord.y, col = "grey90", border = NA)

# mean lines and CI lines - adult
points(fr.grads$adult.calc ~ grad.temps.C, type = "l", col = "black", lwd = 2, xlab = "", lty = 1)
lines(fr.grads$adult.lowerCI ~ grad.temps.C, lty = 1)
lines(fr.grads$adult.upperCI ~ grad.temps.C, lty = 1)

#f CI Shading - JAavg
f.low.rev.JA <- rev(fr.grads$JAavg.lowerCI)
cord.x <- c(grad.temps.C, grad.temps.C.rev)
f.cord.y.JA <- c(fr.grads$JAavg.upperCI, f.low.rev.JA)
polygon(cord.x, f.cord.y.JA, col = "grey90", border = NA)

# mean lines and CI lines - JAavg
points(fr.grads$JAavg.calc ~ grad.temps.C, type = "l", col = "black", lwd = 2, xlab = "", lty = 2)
lines(fr.grads$JAavg.lowerCI ~ grad.temps.C, lty = 1)
lines(fr.grads$JAavg.upperCI ~ grad.temps.C, lty = 1)

text(22.5, 0.01, labels = "Pop. avg. length:", cex = 1)
text(22.5, 0.0085, labels = expression(paste(italic(L),"= 0.85 mm")), cex = 1)
text(18, 0.0175, labels = "Adult length:", cex = 1)
text(18, 0.016, labels = expression(paste(italic(L),"= 1.5 mm")), cex = 1)

legend("topleft", legend = "B", bty = "n", cex = 1.25, adj = 1)
mtext(expression(paste("Exposure/infection temperature - ",italic(T),""[EI]," (",degree,"C)")), side = 1, line = 3, las = 1, cex = 1.2)