### Code for 'Parasite rearing and infection temperatures jointly influence disease 
### transmission and shape seasonality of epidemics. Published in Ecology. (2018)

### Purpose: to simulate epidemics as a function of parasite rearing temperature and exposure/infection temperature
#            *hold some traits constant while others vary to see sensitivity of transmission to each mechanism*

### Table of Contents:
#      1. Set Working Directory, Load Libraries and Data
#      2. Model parameters
#      3. Null Model - u and f are both constant
#      4. Spore Infectivity Model 1 - u is temp-dep, f is constant
#      4. Spore Infectivity Model 2 - u is constant, f  is temp-dep
#      5. Spore Infectivity Model 3 - both u and f are temp-dep
#      7. Calculate epidemic sizes
#      8. Figure 4


######
##### 1. Set Working Directory, Load Libraries, Get Data
######

# Set working directory
setwd("~/Dropbox/Research Hall Lab/Temperature/Temp Spore Infectivity")

## Load libraries
library(deSolve)
library(pracma) # for trapz function to calculate epidemic size via trapezoid method


######
##### 2. Model parameters
######

# Coefficients for temp-dep trait functions
r.ref <- 0.325
r.TA <- 0.390
d.ref <- 0.0118
d.TA <- 1.3
di.ref <- 0.0566
di.TA <- .539
f.ref <- .00539
f.TA <- .874
f.n <- 2.15
u.m.Temp <- -0.0000497
u.m.Tav <- 0.0000906
u.I <- -0.0111
sy.b0 <- -53.2
sy.b1 <- 6.42
sy.b2 <- -0.149

# f for 0.85 mm animals at 25 degrees = 0.00627
0.85^2.15*0.00539*exp(0.874*10000*(1/293.15 - 1/298.15))
f.hot <- 0.00627

# u at 25 degrees = 0.00109
-0.0111 + 298.15*0.0000906 - 298.15*0.0000497
u.hot <- 0.00109

# Spore yield function (in Celcius) - function was fit transformed by /10000, so the *1500 is actually *.15
((-0.149*20*20 + 6.42*20 - 53.2)) # = 15 as fit to data (really = 156,000 spores)
((-0.149*20*20 + 6.42*20 - 53.2))*1500 # = 23,400 spores

# Non-temp-dep traits:
c <- 0.05
m <- 0.9 


######
##### 3. Null Model - u and f are both constant
######

####### Spore Infectivity Null Model - b, d, di, sigma are temperature dependent; f and mu are constant

null.model <- function(t, y, params) {
  S = y[1]; I = y[2]; Z = y[3]; Temp = y[4]; Tav = y[5];
  with(as.list(params),
    {
      dS <- (r.ref*exp(r.TA*10000*(1/293.15 - 1/Temp)) + d.ref*exp(d.TA*10000*(1/293.15 - 1/Temp)))*(S + I)*(1 - c*(S + I)) - d.ref*exp(d.TA*10000*(1/293.15 - 1/Temp))*S - u*f*S*Z
      dI <- u*f*S*Z - di.ref*exp(di.TA*10000*(1/293.15 - 1/Temp))*I
      dZ <- ((sy.b2*(Temp-273.15)*(Temp-273.15) + sy.b1*(Temp-273.15) + sy.b0)*1500)*(di.ref*exp(di.TA*10000*(1/293.15 - 1/Temp)))*I - f*(S+I)*Z - m*Z
      dTemp <- -(0.646785 * 1.06^(t-70)) / (1 + 1.06^(t-70))^2
      dTav <- ( (di.ref*exp(di.TA*10000*(1/293.15 - 1/Temp)))*((sy.b2*(Temp-273.15)*(Temp-273.15) + sy.b1*(Temp-273.15) + sy.b0)*1500)*I*(Temp - Tav)) / Z
      res <- c(dS, dI, dZ, dTemp, dTav)
      list(res)
    }
  )
}

# Time-steps and starting conditions
times = seq(from=1, to=150, by=1)
xstart = c(S = 18, I = .18, Z = 1000, Temp = 298.15, Tav = 298.15)

# Parameters - feeding rate for 0.85 mm animals
null.params = c(c = c, f = f.hot, u = u.hot, m = m)

# Run model
null.model.out <- as.data.frame(lsoda(xstart, times, null.model, null.params, hmax=1/50))

# Calculate prevalence, Tp - Tc, and transmission rate
null.model.out$Prev <- null.model.out$I / (null.model.out$S + null.model.out$I)
null.model.out$TDiff <- null.model.out$Tav - null.model.out$Temp
null.model.out$beta <-  f.hot * u.hot

# Plot
plot(null.model.out$time, null.model.out$S, type = "l", main = "Null", xlab = "Time (days)", ylab = "Density (# / L)", 
     col = "dark blue", xlim = c(0, 150), ylim = c(0, 26), lwd=3)
lines(null.model.out$time, null.model.out$I, col = "blue", lty = 2, lwd=3)
lines(null.model.out$time, null.model.out$Z/10000, col = "red", lty = 2, lwd=3)
lines(null.model.out$time, null.model.out$Prev*26, col = "darkgrey", lty = 1, lwd=3)
lines(null.model.out$time, null.model.out$Temp-273.15, col = "black", lwd = 2)
lines(null.model.out$time, null.model.out$Tav-273.15, col = "darkgrey", lty = 2, lwd = 2)


######
##### 4. Spore Infectivity Model 1 - u is temp-dep, f is constant
######

# Specify model
si.u.model <- function(t, y, params) {
  S = y[1]; I = y[2]; Z = y[3]; Temp = y[4]; Tav = y[5];
  with(as.list(params),
    {
      dS <- (r.ref*exp(r.TA*10000*(1/293.15 - 1/Temp)) + d.ref*exp(d.TA*10000*(1/293.15 - 1/Temp)))*(S + I)*(1 - c*(S + I)) - d.ref*exp(d.TA*10000*(1/293.15 - 1/Temp))*S - (u.I + Tav*u.m.Tav + Temp*u.m.Temp)*f*S*Z
      dI <- (u.I + Tav*u.m.Tav + Temp*u.m.Temp)*f*S*Z - di.ref*exp(di.TA*10000*(1/293.15 - 1/Temp))*I
      dZ <- ((sy.b2*(Temp-273.15)*(Temp-273.15) + sy.b1*(Temp-273.15) + sy.b0)*1500)*(di.ref*exp(di.TA*10000*(1/293.15 - 1/Temp)))*I - f*(S+I)*Z - m*Z
      dTemp <- -(0.646785 * 1.06^(t-70)) / (1 + 1.06^(t-70))^2
      dTav <- ( (di.ref*exp(di.TA*10000*(1/293.15 - 1/Temp)))*((sy.b2*(Temp-273.15)*(Temp-273.15) + sy.b1*(Temp-273.15) + sy.b0)*1500)*I*(Temp - Tav)) / Z
      res <- c(dS, dI, dZ, dTemp, dTav)
      list(res)
    }
  )
}

# Time-steps and starting conditions
times = seq(from=1, to=150, by=1)
xstart = c(S = 18, I = .18, Z = 1000, Temp = 298.15, Tav = 298.15)

# Parameters
si.u.params = c(c = c, f = f.hot, m = m)

# Run model
si.u.model.out <- as.data.frame(lsoda(xstart, times, si.u.model, si.u.params, hmax=1/50))

# Calculate prevalence, Tp - Tc, and transmission rate
si.u.model.out$Prev <- si.u.model.out$I / (si.u.model.out$S + si.u.model.out$I)
si.u.model.out$TDiff <- si.u.model.out$Tav - si.u.model.out$Temp
si.u.model.out$beta <-  f.hot * (u.I + si.u.model.out$Tav*u.m.Tav + si.u.model.out$Temp*u.m.Temp)

# Plot
plot(si.u.model.out$time, si.u.model.out$S, type = "l", main = "u only", xlab = "Time (days)", ylab = "Density (# / L)", 
     col = "dark blue", xlim = c(0, 350), ylim = c(0, 26), lwd=3)
lines(si.u.model.out$time, si.u.model.out$I, col = "blue", lty = 2, lwd=3)
lines(si.u.model.out$time, si.u.model.out$Z/10000, col = "red", lty = 2, lwd=3)
lines(si.u.model.out$time, si.u.model.out$Prev*26, col = "darkgrey", lty = 1, lwd=3)
lines(si.u.model.out$time, si.u.model.out$Temp-273.15, col = "black", lwd = 2)
lines(si.u.model.out$time, si.u.model.out$Tav-273.15, col = "darkgrey", lty = 2, lwd = 2)


######
##### 5. Spore Infectivity Model 2 - u is constant, f  is temp-dep
######

# Specify model
si.f.model <- function(t, y, params) {
  S = y[1]; I = y[2]; Z = y[3]; Temp = y[4]; Tav = y[5];
  with(as.list(params),
    {
      dS <- (r.ref*exp(r.TA*10000*(1/293.15 - 1/Temp)) + d.ref*exp(d.TA*10000*(1/293.15 - 1/Temp)))*(S + I)*(1 - c*(S + I)) - d.ref*exp(d.TA*10000*(1/293.15 - 1/Temp))*S - u*0.85^f.n*f.ref*exp(f.TA*10000*(1/293.15 - 1/Temp))*S*Z
      dI <- u*0.85^f.n*f.ref*exp(f.TA*10000*(1/293.15 - 1/Temp))*S*Z - di.ref*exp(di.TA*10000*(1/293.15 - 1/Temp))*I
      dZ <- ((sy.b2*(Temp-273.15)*(Temp-273.15) + sy.b1*(Temp-273.15) + sy.b0)*1500)*(di.ref*exp(di.TA*10000*(1/293.15 - 1/Temp)))*I - 0.85^f.n*f.ref*exp(f.TA*10000*(1/293.15 - 1/Temp))*(S+I)*Z - m*Z
      dTemp <- -(0.646785 * 1.06^(t-70)) / (1 + 1.06^(t-70))^2
      dTav <- ( (di.ref*exp(di.TA*10000*(1/293.15 - 1/Temp)))*((sy.b2*(Temp-273.15)*(Temp-273.15) + sy.b1*(Temp-273.15) + sy.b0)*1500)*I*(Temp - Tav)) / Z
      res <- c(dS, dI, dZ, dTemp, dTav)
      list(res)
    }
  )
}

# Time-steps and starting conditions
times = seq(from=1, to=150, by=1)
xstart = c(S = 18, I = .18, Z = 1000, Temp = 298.15, Tav = 298.15)

# Parameters
si.f.params = c(c = c, u = u.hot, m = m)

# Run model
si.f.model.out <- as.data.frame(lsoda(xstart, times, si.f.model, si.f.params, hmax=1/50))

# Calculate prevalence, Tp - Tc, and transmission rate
si.f.model.out$Prev <- si.f.model.out$I / (si.f.model.out$S + si.f.model.out$I)
si.f.model.out$TDiff <- si.f.model.out$Tav - si.f.model.out$Temp
si.f.model.out$beta <-  0.85^f.n*f.ref*exp(f.TA*10000*(1/293.15 - 1/si.f.model.out$Temp)) * u.hot

# Plot
plot(si.f.model.out$time, si.f.model.out$S, type = "l", main = "f only", xlab = "Time (days)", ylab = "Density (# / L)", 
     col = "dark blue", xlim = c(0, 350), ylim = c(0, 26), lwd=3)
lines(si.f.model.out$time, si.f.model.out$I, col = "blue", lty = 2, lwd=3)
lines(si.f.model.out$time, si.f.model.out$Z/10000, col = "red", lty = 2, lwd=3)
lines(si.f.model.out$time, si.f.model.out$Prev*26, col = "darkgrey", lty = 1, lwd=3)
lines(si.f.model.out$time, si.f.model.out$Temp-273.15, col = "black", lwd = 2)
lines(si.f.model.out$time, si.f.model.out$Tav-273.15, col = "darkgrey", lty = 2, lwd = 2)


######
##### 6. Spore Infectivity Model 3 - both u and f are temp-dep
######

# Specify model
si.both.model <- function(t, y, params) {
  S = y[1]; I = y[2]; Z = y[3]; Temp = y[4]; Tav = y[5];
  with(as.list(params),
{
  dS <- (r.ref*exp(r.TA*10000*(1/293.15 - 1/Temp)) + d.ref*exp(d.TA*10000*(1/293.15 - 1/Temp)))*(S + I)*(1 - c*(S + I)) - d.ref*exp(d.TA*10000*(1/293.15 - 1/Temp))*S - (u.I + Tav*u.m.Tav + Temp*u.m.Temp)*0.85^f.n*f.ref*exp(f.TA*10000*(1/293.15 - 1/Temp))*S*Z
  dI <- (u.I + Tav*u.m.Tav + Temp*u.m.Temp)*0.85^f.n*f.ref*exp(f.TA*10000*(1/293.15 - 1/Temp))*S*Z - di.ref*exp(di.TA*10000*(1/293.15 - 1/Temp))*I
  dZ <- ((sy.b2*(Temp-273.15)*(Temp-273.15) + sy.b1*(Temp-273.15) + sy.b0)*1500)*(di.ref*exp(di.TA*10000*(1/293.15 - 1/Temp)))*I - 0.85^f.n*f.ref*exp(f.TA*10000*(1/293.15 - 1/Temp))*(S+I)*Z - m*Z
  dTemp <- -(0.646785 * 1.06^(t-70)) / (1 + 1.06^(t-70))^2
  dTav <- ( (di.ref*exp(di.TA*10000*(1/293.15 - 1/Temp)))*((sy.b2*(Temp-273.15)*(Temp-273.15) + sy.b1*(Temp-273.15) + sy.b0)*1500)*I*(Temp - Tav)) / Z
  res <- c(dS, dI, dZ, dTemp, dTav)
  list(res)
}
  )
}

# Time-steps and starting conditions
times = seq(from=1, to=150, by=1)
xstart = c(S = 18, I = .18, Z = 1000, Temp = 298.15, Tav = 298.15)

# Parameters
si.both.params = c(c = c, m = m)

# Run model
si.both.model.out <- as.data.frame(lsoda(xstart, times, si.both.model, si.both.params, hmax=1/50))

# Calculate prevalence, Tp - Tc, and transmission rate
si.both.model.out$Prev <- si.both.model.out$I / (si.both.model.out$S + si.both.model.out$I)
si.both.model.out$TDiff <- si.both.model.out$Tav - si.both.model.out$Temp
si.both.model.out$beta <-  (u.I + si.both.model.out$Tav*u.m.Tav + si.both.model.out$Temp*u.m.Temp)*0.85^f.n*f.ref*exp(f.TA*10000*(1/293.15 - 1/si.both.model.out$Temp))

# Plot
plot(si.both.model.out$time, si.both.model.out$S, type = "l", main = "both", xlab = "Time (days)", ylab = "Density (# / L)", 
     col = "dark blue", xlim = c(0, 350), ylim = c(0, 26), lwd=3)
lines(si.both.model.out$time, si.both.model.out$I, col = "blue", lty = 2, lwd=3)
lines(si.both.model.out$time, si.both.model.out$Z/10000, col = "red", lty = 2, lwd=3)
lines(si.both.model.out$time, si.both.model.out$Prev*26, col = "darkgrey", lty = 1, lwd=3)
lines(si.both.model.out$time, si.both.model.out$Temp-273.15, col = "black", lwd = 2)
lines(si.both.model.out$time, si.both.model.out$Tav-273.15, col = "darkgrey", lty = 2, lwd = 2)

fig4.list <- list(null.model.out, si.u.model.out, si.f.model.out, si.both.model.out)
save(fig4.list, file = "fig4.sims.Rsave")


######
##### 7. Calculate epidemic sizes
######

# Calculate epidemic sizes
epi.null <- trapz(x = null.model.out$time, y = null.model.out$Prev)
epi.u <- trapz(x = si.u.model.out$time, y = si.u.model.out$Prev)
epi.f <- trapz(x = si.f.model.out$time, y = si.f.model.out$Prev)
epi.both <- trapz(x = si.both.model.out$time, y = si.both.model.out$Prev)

# Calculate % difference in epidemic size
(epi.null - epi.u) / epi.null # for u only
(epi.null - epi.f) / epi.null # for f only
(epi.null - epi.both) / epi.null # for both
((epi.null - epi.f) + (epi.null  - epi.f)) / epi.null # expectation given additive effects

# Get day of peak lag between T and Tav
which.max(null.model.out$TDiff)
which.max(si.u.model.out$TDiff)
which.max(si.f.model.out$TDiff)
which.max(si.both.model.out$TDiff)

# Get max lag between T and Tav
max(null.model.out$TDiff)
max(si.u.model.out$TDiff)
max(si.f.model.out$TDiff)
max(si.both.model.out$TDiff)

# Get day of peak prevalence
which.max(null.model.out$Prev)
which.max(si.u.model.out$Prev)
which.max(si.f.model.out$Prev)
which.max(si.both.model.out$Prev)


##################### Plot comparing prevalence in different models

load("fig4.sims.Rsave")
null.model.out <- fig4.list[[1]]
si.u.model.out <- fig4.list[[2]]
si.f.model.out <- fig4.list[[3]]
si.both.model.out <- fig4.list[[4]]

# Do first two panels and then combine with third panel in paint
par(mfrow = c(1, 1), mar = c(4, 5, 1, 1), mgp =  c(2.75, 1, 0), las = 1, oma = c(0, 0, 0, 0))

##### Temp Panel

plot(si.both.model.out$time, si.both.model.out$Temp-273.15, type = "l", main = "", xlab = "", ylab = expression(paste("Temperature (",degree,"C)")), 
     col = "turquoise3", xlim = c(0, 150), ylim = c(13, 28), lwd=3, cex.axis = 1, cex.lab = 1.25)
points(si.both.model.out$time, si.both.model.out$Tav-273.15, col = "black", lty = 2, type = "l", lwd = 2)
points(x = 70, y = 19.65, pch = 21, bg = "white", cex = 1.25)

legend("topleft", legend = "A", bty = "n", cex = 1.25, adj = 1)
a <- expression(paste("T"[EI]))
b <- expression(paste("T"[R]))
legend(x = 100, y = 25, legend = c(a, b), lty = c(1, 2), col = c("turquoise3", "black"), lwd = 2, bty = "n", cex = 1.25)

text(x = 140, y = 13.5, labels = expression(paste(italic(T[min]))), cex = 1.1)
text(x = 10, y = 25.76, labels = expression(paste(italic(T[max]))), cex = 1.1)
text(x = 61, y = 19.65, labels = expression(paste(italic(D))), cex = 1.1)

##### Transmission Rate Panel

plot(null.model.out$time, null.model.out$beta*1000000, type = "l", main = "", xlab = "", ylab = expression(paste("Transmission rate - ",beta," (L spore"^-1," day"^-1,"10"^-6,")")), 
     col = "black", xlim = c(0, 150), ylim = c(0, 8), lwd=2, cex.lab = 1.2, cex.axis = 1)
lines(si.u.model.out$time, si.u.model.out$beta*1000000, col = "darkorchid2", lty = 1, lwd=2)
lines(si.f.model.out$time, si.f.model.out$beta*1000000, col = "black", lty = 2, lwd=2)
lines(si.both.model.out$time, si.both.model.out$beta*1000000, col = "darkorchid2", lty = 2, lwd=2)

leg.a <- expression(paste(italic(f)," and ",italic(u)))
leg.b <- expression(paste(italic(f)," and ",italic(u),"(",italic(T),")"))
leg.c <- expression(paste(italic(f),"(",italic(T),") and ",italic(u)))
leg.d <- expression(paste(italic(f),"(",italic(T),") and ",italic(u),"(",italic(T),")"))

legend(x = 5, y = 3, bty = "n", legend = c(leg.a, leg.b, leg.c, leg.d),
       col = c("black", "darkorchid2", "black", "darkorchid2"), lty = c(1, 1, 2, 2), lwd = 2, cex = 1)
legend("topleft", legend = "B", bty = "n", cex = 1.25, adj = 1)

##### Prevalence Panel

plot(null.model.out$time, null.model.out$Prev, type = "l", main = "", xlab = "Time (days)", ylab = "Infection prevalence", 
     col = "black", xlim = c(0, 150), ylim = c(0, 1), lwd=2, cex.lab = 1.25, cex.axis = 1)
lines(si.u.model.out$time, si.u.model.out$Prev, col = "darkorchid2", lty = 1, lwd=2)
lines(si.f.model.out$time, si.f.model.out$Prev, col = "black", lty = 2, lwd=2)
lines(si.both.model.out$time, si.both.model.out$Prev, col = "darkorchid2", lty = 2, lwd=2)
legend("topleft", legend = "C", bty = "n", cex = 1.25, adj = 1)

par(mfrow = c(1, 1), mar = c(4.7, 5.2, 1, 1), mgp =  c(3.4, 1, 0), las = 1)

# Panel of TC - TP Lag for Appendix
plot(si.both.model.out$time, si.both.model.out$TDiff, type = "l", main = "", xlab = "Time (days)", ylab = expression(paste("Temperature Lag: ",italic(T[EI] -T[R])," (",degree,"C)")), 
     col = "darkgrey", xlim = c(0, 150), ylim = c(0, .2), lwd=3, cex.axis = 1, cex.lab = 1.25, cex.axis = 1, lty = 2)
points(si.u.model.out$time, si.u.model.out$TDiff, type = "l", lwd = 2, lty = 1, col = "grey")
points(si.f.model.out$time, si.f.model.out$TDiff, type = "l", lwd = 2, lty = 2, col = "black")
points(null.model.out$time, null.model.out$TDiff, type = "l", lwd = 2, lty = 1, col = "black")

leg.a <- expression(paste(italic(f)," and ",italic(u)))
leg.b <- expression(paste(italic(f)," and ",italic(u),"(",italic(T),")"))
leg.c <- expression(paste(italic(f),"(",italic(T),") and ",italic(u)))
leg.d <- expression(paste(italic(f),"(",italic(T),") and ",italic(u),"(",italic(T),")"))

legend(x = 86, y = 0.2, bty = "n", legend = c(leg.a, leg.b, leg.c, leg.d),
       col = c("black", "darkorchid2", "black", "darkorchid2"), lty = c(1, 1, 2, 2), lwd = 2, cex = 1)
legend("topleft", legend = "A", bty = "n", cex = 1.25, adj = 1)