### Marta Shocket, Indiana University, Stanford University
### Code for 'Parasite rearing and infection temperatures jointly influence disease 
### transmission and shape seasonality of epidemics. Published in Ecology. (2018)

### Purpose: to simulate epidemics as a function of parasite rearing temperature and exposure/infection temperature
#            *all traits depend on temperature to see variation with different cooling profiles*

### Table of Contents:
#      1. Set Working Directory, Load Libraries and Data
#      2. Model parameters
#      3. Starting Temp Model
#      4. Cooling Date Model
#      5. Cooling Rate Model
#      6. Figure 5


######
##### 1. Set Working Directory, Load Libraries, Get Data
######

# Set working directory
setwd("~/Dropbox/Research Hall Lab/Temperature/Temp Spore Infectivity")

# Load libraries
library(deSolve)
library(pracma) # for trapz function


######
##### 2. Model parameters
######

# Coefficients for temp-dep trait functions
r.ref <- 0.325
r.TA <- 0.390
d.ref <- 0.0118
d.TA <- 1.3
di.ref <- 0.0566
di.TA <- .539
f.ref <- .00539
f.TA <- .874
f.n <- 2.15
u.m.Temp <- -0.0000497
u.m.Tav <- 0.0000906
u.I <- -0.0111
sy.b0 <- -53.2
sy.b1 <- 6.42
sy.b2 <- -0.149

# Non-temp-dep traits:
c <- 0.05
m <- 0.9 


######
##### 3. Starting Temp Model
######

# Calculate derivitive
fx = expression(st.param/(1 + 1.06^(x - 70)) + 288.15, 'x')
D(fx, 'x')

### Generate sequence of parameters for the current temp equation
# for parameter plot
st.param <- seq(4, 10, 0.2)
st.seq <- st.param * log(1.06)
st.tmax.K <- st.param + 288.15
st.tmax.C <- st.param + 15

# for example epidemics plots
st.ee.ind <- c(1, 8, 16, 24, 31) # index #s of parameters used in the example epidemics
st.ee <- st.param[st.ee.ind]
st.ee.seq <- st.ee * log(1.06)
st.ee.tmax.K <- st.ee + 288.15
st.ee.tmax.C <- st.ee + 15

### The model
st.model <- function(t, y, params) {
  S = y[1]; I = y[2]; Z = y[3]; Temp = y[4]; Tav = y[5];
  with(as.list(params),
{
  dS <- (r.ref*exp(r.TA*10000*(1/293.15 - 1/Temp)) + d.ref*exp(d.TA*10000*(1/293.15 - 1/Temp)))*(S + I)*(1 - c*(S + I)) - d.ref*exp(d.TA*10000*(1/293.15 - 1/Temp))*S - (u.I + Tav*u.m.Tav + Temp*u.m.Temp)*0.85^f.n*f.ref*exp(f.TA*10000*(1/293.15 - 1/Temp))*S*Z
  dI <- (u.I + Tav*u.m.Tav + Temp*u.m.Temp)*0.85^f.n*f.ref*exp(f.TA*10000*(1/293.15 - 1/Temp))*S*Z - di.ref*exp(di.TA*10000*(1/293.15 - 1/Temp))*I
  dZ <- ((sy.b2*(Temp-273.15)*(Temp-273.15) + sy.b1*(Temp-273.15) + sy.b0)*1500)*(di.ref*exp(di.TA*10000*(1/293.15 - 1/Temp)))*I - 0.85^f.n*f.ref*exp(f.TA*10000*(1/293.15 - 1/Temp))*(S+I)*Z - m*Z
  dTemp <- -(st * 1.06^(t-70)) / (1 + 1.06^(t-70))^2
  dTav <- ( (di.ref*exp(di.TA*10000*(1/293.15 - 1/Temp)))*((sy.b2*(Temp-273.15)*(Temp-273.15) + sy.b1*(Temp-273.15) + sy.b0)*1500)*I*(Temp - Tav)) / Z
  res <- c(dS, dI, dZ, dTemp, dTav)
  list(res)
}
  )
}

### Time-steps and starting conditions
times = seq(from=1, to=150, by=.1)

### Output vector for parameter plot
st.episize <- numeric(length(st.seq))
st.maxdate <- numeric(length(st.seq))

### Loop for parameter plot
for (i in 1:length(st.seq)) {
  
  st.params = c(c = c, m = m, st = st.seq[i])
  xstart = c(S = 18, I = .18, Z = 1000, Temp = st.tmax.K[i], Tav = st.tmax.K[i])
  
  model.out <- as.data.frame(lsoda(xstart, times, st.model, st.params, hmax=1/50))
  model.out$Prev <- model.out$I / (model.out$I + model.out$S)
  
  st.episize[i] <- trapz(model.out$time, model.out$Prev)
  st.maxdate[i] <- model.out$time[which.max(model.out$Prev)]
  
}

### Check output for parameter plot
par(mfrow = c(1,1), mar = c(5, 5, 1, 1), las = 1)
plot(st.episize ~ st.tmax.C, type = "l", main = "", xlab = expression(paste("Parameter ",italic(T[max]))), ylab = expression(paste("Epidemic Size")), 
     col = "black", xlim = c(19, 25), ylim = c(0, 60), lwd=3, cex.axis = 1.25, cex.lab = 1.25)
plot(st.maxdate ~ st.tmax.C, type = "l", main = "", xlab = expression(paste("Parameter ",italic(T[max]))), ylab = expression(paste("Epidemic Peak Date")), 
     col = "black", xlim = c(19, 25), ylim = c(50, 100), lwd=3, cex.axis = 1.25, cex.lab = 1.25)

### Output list for example epidemics plots
st.list <- list()

### Loop for example epidemics plot
for (i in 1:length(st.ee.seq)) {
  
  st.params = c(c = c, m = m, st = st.ee.seq[i])
  xstart = c(S = 18, I = .18, Z = 1000, Temp = st.ee.tmax.K[i], Tav = st.ee.tmax.K[i])
  
  model.out <- as.data.frame(lsoda(xstart, times, st.model, st.params, hmax=1/50))
  model.out$Prev <- model.out$I / (model.out$I + model.out$S)
  
  st.list[[i]] <- model.out
  
}

### Check output for example epidemics plot
par(mfrow = c(1,1), mar = c(5, 5, 1, 1), las = 1)
plot(st.list[[1]]$Prev ~ st.list[[1]]$time, type = "l", main = "", xlab = expression(paste("Parameter ",italic(T[max]))), ylab = expression(paste("Epidemic Size")), 
     col = "black", xlim = c(0,150), ylim = c(0, 1), lwd=3, cex.axis = 1.25, cex.lab = 1.25)
points(st.list[[2]]$Prev ~ st.list[[1]]$time, type = "l", lwd = 2)
points(st.list[[3]]$Prev ~ st.list[[1]]$time, type = "l", lwd = 2)
points(st.list[[4]]$Prev ~ st.list[[1]]$time, type = "l", lwd = 2)
points(st.list[[5]]$Prev ~ st.list[[1]]$time, type = "l", lwd = 2)


######
##### 4. Cooling Date Model
######

#### Sequence of parameters for the current temp equation
# for parameter plot
cd.seq <- seq(60, 100, 1)

# for example epidemics plots
cd.ee.ind <- c(1, 11, 21, 31, 41) # index #s of parameters used in the example epidemics
cd.ee.seq <- cd.seq[cd.ee.ind]

# The model
cd.model <- function(t, y, params) {
  S = y[1]; I = y[2]; Z = y[3]; Temp = y[4]; Tav = y[5];
  with(as.list(params),
{
  dS <- (r.ref*exp(r.TA*10000*(1/293.15 - 1/Temp)) + d.ref*exp(d.TA*10000*(1/293.15 - 1/Temp)))*(S + I)*(1 - c*(S + I)) - d.ref*exp(d.TA*10000*(1/293.15 - 1/Temp))*S - (u.I + Tav*u.m.Tav + Temp*u.m.Temp)*0.85^f.n*f.ref*exp(f.TA*10000*(1/293.15 - 1/Temp))*S*Z
  dI <- (u.I + Tav*u.m.Tav + Temp*u.m.Temp)*0.85^f.n*f.ref*exp(f.TA*10000*(1/293.15 - 1/Temp))*S*Z - di.ref*exp(di.TA*10000*(1/293.15 - 1/Temp))*I
  dZ <- ((sy.b2*(Temp-273.15)*(Temp-273.15) + sy.b1*(Temp-273.15) + sy.b0)*1500)*(di.ref*exp(di.TA*10000*(1/293.15 - 1/Temp)))*I - 0.85^f.n*f.ref*exp(f.TA*10000*(1/293.15 - 1/Temp))*(S+I)*Z - m*Z
  dTemp <- -(0.646785 * 1.06^(t-cd)) / (1 + 1.06^(t-cd))^2
  dTav <- ( (di.ref*exp(di.TA*10000*(1/293.15 - 1/Temp)))*((sy.b2*(Temp-273.15)*(Temp-273.15) + sy.b1*(Temp-273.15) + sy.b0)*1500)*I*(Temp - Tav)) / Z
  res <- c(dS, dI, dZ, dTemp, dTav)
  list(res)
}
  )
}

# Time-steps and starting conditions
times = seq(from=1, to=150, by=.1)
xstart = c(S = 18, I = .18, Z = 1000, Temp = 298.15, Tav = 298.15)

# Output vector
cd.episize <- numeric(length(cd.seq))
cd.maxdate <- numeric(length(cd.seq))

### Loop for parameter plot
for (i in 1:length(cd.seq)) {
  
  cd.params = c(c = c, m = m, cd = cd.seq[i])
  
  model.out <- as.data.frame(lsoda(xstart, times, cd.model, cd.params, hmax=1/50))
  model.out$Prev <- model.out$I / (model.out$I + model.out$S)
  
  cd.episize[i] <- trapz(model.out$time, model.out$Prev)
  cd.maxdate[i] <- model.out$time[which.max(model.out$Prev)]
  
}

### Check output for parameter plot
par(mfrow = c(1,1), mar = c(5, 5, 1, 1), las = 1)
plot(cd.episize ~ cd.seq, type = "l", main = "", xlab = expression(paste("Parameter ",italic(D))), ylab = expression(paste("Epidemic Size")), 
     col = "black", xlim = c(60, 100), ylim = c(0, 55), lwd=3, cex.axis = 1.25, cex.lab = 1.25)
plot(cd.maxdate ~ cd.seq, type = "l", main = "", xlab = expression(paste("Parameter ",italic(D))), ylab = expression(paste("Epidemic Peak Date")), 
     col = "black", xlim = c(60, 100), ylim = c(50, 100), lwd=3, cex.axis = 1.25, cex.lab = 1.25)

### Output list for example epidemics plots
cd.list <- list()

### Loop for example epidemics plot
for (i in 1:length(cd.ee.seq)) {
  
  cd.params = c(c = c, m = m, cd = cd.ee.seq[i])
  
  model.out <- as.data.frame(lsoda(xstart, times, cd.model, cd.params, hmax=1/50))
  model.out$Prev <- model.out$I / (model.out$I + model.out$S)
  
  cd.list[[i]] <- model.out
  
}

### Check output for example epidemics plot
par(mfrow = c(1,1), mar = c(5, 5, 1, 1), las = 1)
plot(cd.list[[1]]$Prev ~ st.list[[1]]$time, type = "l", main = "", xlab = expression(paste("Parameter ",italic(T[max]))), ylab = expression(paste("Epidemic Size")), 
     col = "black", xlim = c(0,150), ylim = c(0, 1), lwd=3, cex.axis = 1.25, cex.lab = 1.25)
points(cd.list[[2]]$Prev ~ st.list[[1]]$time, type = "l", lwd = 2)
points(cd.list[[3]]$Prev ~ st.list[[1]]$time, type = "l", lwd = 2)
points(cd.list[[4]]$Prev ~ st.list[[1]]$time, type = "l", lwd = 2)
points(cd.list[[5]]$Prev ~ st.list[[1]]$time, type = "l", lwd = 2)


######
##### 5. Cooling Rate Model
######

# Calculate derivitive
fx = expression(10/(1 + cr^(x - 70)) + 288.15, 'x')
D(fx, 'x')

# Generate sequence of parameters for the current temp equation
# for parameter plot
cr.seq <- seq(1.04, 1.18, 0.005)

# for example epidemics plot
cr.ee.ind <- c(1, 5, 11, 19, 29) # index #s of parameters used in the example epidemics
cr.ee.seq <- cr.seq[cr.ee.ind]

# The temp only model to figure out Tmax offsets - to make all the cooling trajectories go through the same middle point
cr.model.temp <- function(t, y, params) {
  Temp = y[1];
  with(as.list(params),
{
  dTemp <- -(10 * log(cr) * cr^(t-70)) / (1 + cr^(t-70))^2
  res <- c(dTemp)
  list(res)
}
  )
}

times = seq(from=1, to=150, by=1)
xstart = c(Temp = 298.15)
t70diff <- numeric(length(cr.seq))

for (i in 1:length(cr.seq)) {
  
  cr.params = c(cr = cr.seq[i])
  
  model.out <- as.data.frame(lsoda(xstart, times, cr.model.temp, cr.params, hmax=1/50))
  t70diff[i]  <- model.out$Temp[70] - 293.3263 #293.3263 is the temperature on day 70 with base parameters, i.e., cr = 1.06
  
}

t70diff.ee <- t70diff[cr.ee.ind]

# The model
cr.model <- function(t, y, params) {
  S = y[1]; I = y[2]; Z = y[3]; Temp = y[4]; Tav = y[5];
  with(as.list(params),
{
  dS <- (r.ref*exp(r.TA*10000*(1/293.15 - 1/Temp)) + d.ref*exp(d.TA*10000*(1/293.15 - 1/Temp)))*(S + I)*(1 - c*(S + I)) - d.ref*exp(d.TA*10000*(1/293.15 - 1/Temp))*S - (u.I + Tav*u.m.Tav + Temp*u.m.Temp)*0.85^f.n*f.ref*exp(f.TA*10000*(1/293.15 - 1/Temp))*S*Z
  dI <- (u.I + Tav*u.m.Tav + Temp*u.m.Temp)*0.85^f.n*f.ref*exp(f.TA*10000*(1/293.15 - 1/Temp))*S*Z - di.ref*exp(di.TA*10000*(1/293.15 - 1/Temp))*I
  dZ <- ((sy.b2*(Temp-273.15)*(Temp-273.15) + sy.b1*(Temp-273.15) + sy.b0)*1500)*(di.ref*exp(di.TA*10000*(1/293.15 - 1/Temp)))*I - 0.85^f.n*f.ref*exp(f.TA*10000*(1/293.15 - 1/Temp))*(S+I)*Z - m*Z
  dTemp <- -(10 * log(cr) * cr^(t-70)) / (1 + cr^(t-70))^2
  dTav <- ( (di.ref*exp(di.TA*10000*(1/293.15 - 1/Temp)))*((sy.b2*(Temp-273.15)*(Temp-273.15) + sy.b1*(Temp-273.15) + sy.b0)*1500)*I*(Temp - Tav)) / Z
  res <- c(dS, dI, dZ, dTemp, dTav)
  list(res)
}
  )
}

# Time-steps and starting conditions
times = seq(from=1, to=150, by=.1)

# Output vector
cr.episize <- numeric(length(cr.seq))
cr.maxdate <- numeric(length(cr.seq))

# Loop for parameter plot
for (i in 1:length(cr.seq)) {
  
  cr.params = c(c = c, m = m, cr = cr.seq[i])
  xstart = c(S = 18, I = .18, Z = 1000, Temp = 298.15 - t70diff[i], Tav = 298.15 - t70diff[i])
  
  model.out <- as.data.frame(lsoda(xstart, times, cr.model, cr.params, hmax=1/50))
  model.out$Prev <- model.out$I / (model.out$I + model.out$S)
  
  cr.episize[i] <- trapz(model.out$time, model.out$Prev)
  cr.maxdate[i] <- model.out$time[which.max(model.out$Prev)]
  
}

# Check output for parameter plot
par(mfrow = c(1,1), mar = c(5, 5, 1, 1), las = 1)
plot(cr.episize ~ cr.seq, type = "l", main = "", xlab = expression(paste("Parameter ",italic(R))), ylab = expression(paste("Epidemic Size")), 
     col = "black", xlim = c(1.04, 1.18), ylim = c(0, 60), lwd=3, cex.axis = 1.25, cex.lab = 1.25)
plot(cr.maxdate ~ cr.seq, type = "l", main = "", xlab = expression(paste("Parameter ",italic(R))), ylab = expression(paste("Epidemic Peak Date")), 
     col = "black", xlim = c(1.04, 1.18), ylim = c(50, 100), lwd=3, cex.axis = 1.25, cex.lab = 1.25)

### Output list for example epidemics plots
cr.list <- list()

# Loop for example epidemic plots
for (i in 1:length(cr.ee.seq)) {
  
  cr.params = c(c = c, m = m, cr = cr.ee.seq[i])
  xstart = c(S = 18, I = .18, Z = 1000, Temp = 298.15 - t70diff.ee[i], Tav = 298.15 - t70diff.ee[i])
  
  model.out <- as.data.frame(lsoda(xstart, times, cr.model, cr.params, hmax=1/50))
  model.out$Prev <- model.out$I / (model.out$I + model.out$S)
  
  cr.list[[i]] <- model.out
  
}

# Check temp in plots
plot(cr.list[[5]]$Temp-273.15 ~ cr.list[[1]]$time, type = "l", main = "", xlab = "", ylab = expression(paste("Temperature (",degree,"C)")), 
     col = "black", xlim = c(0, 150), ylim = c(15, 25), lwd=2, cex.axis = 1.25, cex.lab = 1.5)
points(cr.list[[4]]$Temp-273.15 ~ cr.list[[1]]$time, type = "l", col = "black", lwd=2, lty = 5)
points(cr.list[[3]]$Temp-273.15 ~ cr.list[[1]]$time, type = "l", col = "black", lwd=2, lty = 2)
points(cr.list[[2]]$Temp-273.15 ~ cr.list[[1]]$time, type = "l", col = "black", lwd=2, lty = 4)
points(cr.list[[1]]$Temp-273.15 ~ cr.list[[1]]$time, type = "l", col = "black", lwd=2, lty = 3)

### Check output for example epidemics plot
par(mfrow = c(1,1), mar = c(5, 5, 1, 1), las = 1)
plot(cr.list[[1]]$Prev ~ st.list[[1]]$time, type = "l", main = "", xlab = expression(paste("Parameter ",italic(T[max]))), ylab = expression(paste("Epidemic Size")), 
     col = "black", xlim = c(0,150), ylim = c(0, 1), lwd=3, cex.axis = 1.25, cex.lab = 1.25)
points(cr.list[[2]]$Prev ~ st.list[[1]]$time, type = "l", lwd = 2)
points(cr.list[[3]]$Prev ~ st.list[[1]]$time, type = "l", lwd = 2)
points(cr.list[[4]]$Prev ~ st.list[[1]]$time, type = "l", lwd = 2)
points(cr.list[[5]]$Prev ~ st.list[[1]]$time, type = "l", lwd = 2)

####### Save data in a big list
Fig5list <- list(st.list, cd.list, cr.list, st.episize, st.maxdate, cd.episize, cd.maxdate, cr.episize, cr.maxdate)
save(Fig5list, file = "Fig5list.Rsave")


######
##### 6. Figure 5
######

######## Load Data from the big list
load("Fig5list.Rsave")
st.list <- Fig5list[[1]]
cd.list  <- Fig5list[[2]]
cr.list <- Fig5list[[3]]
st.episize <- Fig5list[[4]]
st.maxdate <- Fig5list[[5]]
cd.episize <- Fig5list[[6]]
cd.maxdate <- Fig5list[[7]]
cr.episize <- Fig5list[[8]]
cr.maxdate <- Fig5list[[9]]

# for parameter plot
st.param <- seq(4, 10, 0.2)
st.seq <- st.param * log(1.06)
st.tmax.C <- st.param + 15

# for example epidemics plots
st.ee.ind <- c(1, 8, 16, 24, 31) 
st.ee <- st.param[st.ee.ind]
st.ee.seq <- st.ee * log(1.06)
st.ee.tmax.C <- st.ee + 15

# for parameter plot
cd.seq <- seq(60, 100, 1)

# for example epidemics plots
cd.ee.ind <- c(1, 11, 21, 31, 41) 
cd.ee.seq <- cd.seq[cd.ee.ind]

# for parameter plot
cr.seq <- seq(1.04, 1.18, 0.005)

# for example epidemics plot
cr.ee.ind <- c(1, 5, 11, 19, 29)
cr.ee.seq <- cr.seq[cr.ee.ind]

st.es.list <- c(trapz(st.list[[1]]$time, st.list[[1]]$Prev), trapz(st.list[[2]]$time, st.list[[2]]$Prev), trapz(st.list[[3]]$time, st.list[[3]]$Prev), trapz(st.list[[4]]$time, st.list[[4]]$Prev), trapz(st.list[[5]]$time, st.list[[5]]$Prev))
st.md.list <- c(st.list[[1]]$time[which.max(st.list[[1]]$Prev)], st.list[[2]]$time[which.max(st.list[[2]]$Prev)], st.list[[3]]$time[which.max(st.list[[3]]$Prev)], st.list[[4]]$time[which.max(st.list[[4]]$Prev)], st.list[[5]]$time[which.max(st.list[[5]]$Prev)])

cd.es.list <- c(trapz(cd.list[[1]]$time, cd.list[[1]]$Prev), trapz(cd.list[[2]]$time, cd.list[[2]]$Prev), trapz(cd.list[[3]]$time, cd.list[[3]]$Prev), trapz(cd.list[[4]]$time, cd.list[[4]]$Prev), trapz(cd.list[[5]]$time, cd.list[[5]]$Prev))
cd.md.list <- c(cd.list[[1]]$time[which.max(cd.list[[1]]$Prev)], cd.list[[2]]$time[which.max(cd.list[[2]]$Prev)], cd.list[[3]]$time[which.max(cd.list[[3]]$Prev)], cd.list[[4]]$time[which.max(cd.list[[4]]$Prev)], cd.list[[5]]$time[which.max(cd.list[[5]]$Prev)])

cr.es.list <- c(trapz(cr.list[[1]]$time, cr.list[[1]]$Prev), trapz(cr.list[[2]]$time, cr.list[[2]]$Prev), trapz(cr.list[[3]]$time, cr.list[[3]]$Prev), trapz(cr.list[[4]]$time, cr.list[[4]]$Prev), trapz(cr.list[[5]]$time, cr.list[[5]]$Prev))
cr.md.list <- c(cr.list[[1]]$time[which.max(cr.list[[1]]$Prev)], cr.list[[2]]$time[which.max(cr.list[[2]]$Prev)], cr.list[[3]]$time[which.max(cr.list[[3]]$Prev)], cr.list[[4]]$time[which.max(cr.list[[4]]$Prev)], cr.list[[5]]$time[which.max(cr.list[[5]]$Prev)])

par(mfrow = c(1, 3))
par(mfrow = c(3, 3), mar = c(2, 5, 1, 1), oma = c(2.5, 0, 2, 4), mgp = c(3, 1, 0), las = 1)

# A) Temps for Starting Temp
plot(st.list[[5]]$Temp-273.15 ~ st.list[[1]]$time, type = "l", xlab = "", ylab = expression(paste("Temperature (",degree,"C)")), 
     col = "red3", xlim = c(0, 150), ylim = c(14, 26.5), lwd=2, cex.axis = 1.25, cex.lab = 1.5, cex.main = 1.75)
points(st.list[[4]]$Temp-273.15 ~ st.list[[1]]$time, type = "l", col = "chocolate2", lwd=2, lty = 5)
points(st.list[[3]]$Temp-273.15 ~ st.list[[1]]$time, type = "l", col = "limegreen", lwd=2, lty = 2)
points(st.list[[2]]$Temp-273.15 ~ st.list[[1]]$time, type = "l", col = "dodgerblue", lwd=2, lty = 4)
points(st.list[[1]]$Temp-273.15 ~ st.list[[1]]$time, type = "l", col = "purple3", lwd=2, lty = 3)
mtext(text = "Cooling Scenario", cex = 1.25, line = 0.5)
text(x = 105, y = 24, labels = "Max. Temp.", cex = 1.75)
legend("topleft", legend = "A", bty = "n", cex = 1.5, adj = c(0.9, 0.2))

# B) Epidemics for Starting Temp
plot(st.list[[5]]$Prev ~ st.list[[1]]$time, type = "l", main = "", xlab = "", ylab = "Infection prevalence", 
     col = "red3", xlim = c(0, 150), ylim = c(0, 0.6), lwd=2, cex.lab = 1.5, cex.axis = 1.25, lty = 1, cex.main = 1.75)
lines(st.list[[4]]$Prev ~ st.list[[1]]$time, col = "chocolate2", lty = 5, lwd=2)
lines(st.list[[3]]$Prev ~ st.list[[1]]$time, col = "limegreen", lty = 2, lwd=2)
lines(st.list[[2]]$Prev ~ st.list[[1]]$time, col = "dodgerblue", lty = 4, lwd=2)
lines(st.list[[1]]$Prev ~ st.list[[1]]$time, col = "purple3", lty = 3, lwd=2)
mtext(text = "Epidemic Dynamics", cex = 1.25, line = 0.5)
legend("topleft", legend = "B", bty = "n", cex = 1.5, adj = c(0.9, 0.2))

text(x = 115, y = .58, labels = expression(paste(italic(T[max])," =")), cex = 1.25)
legend(x = 95, y = .57, legend= c("25", "23.6", "22", "20.4", "19"), lty = c(1, 5, 2, 4, 3), pch = NA, bty = "n", cex = 1.25, lwd = 2, col = c("red3", "chocolate2", "limegreen", "dodgerblue", "purple3"))
legend(x = 105, y = .57, legend= c("", "", "", "", ""), lty = c(0, 0, 0, 0, 0), pch = 21, pt.bg = c("red3", "chocolate2", "limegreen", "dodgerblue", "purple3"), bty = "n", cex = 1.25, pt.cex = 1.75)

# C) Parameter plot for Starting Temp
plot(st.episize.b ~ st.tmax.C, type = "l", main = "", xlab = expression(paste("Parameter ",italic(T[max]))), ylab = "Epidemic size (prevalence days)", 
     col = "black", xlim = c(19, 25), ylim = c(0, 51), lwd=2, cex.axis = 1.25, cex.lab = 1.5, cex.main = 1.75)
points(st.es.list ~ st.ee.tmax.C, pch = 21, bg = c("purple3", "dodgerblue", "limegreen", "chocolate2", "red3"), cex = 1.75)
par(new = TRUE)
plot(st.maxdate.b ~ st.tmax.C, type = "l", lwd = 2, col = "darkgrey",  ylim = c(52, 73), xlim = c(19, 25), axes = FALSE, bty = "n",
     ylab = "", xlab ="", lty = 1)
axis(side = 4, cex.axis = 1.25)
mtext(text = "Epidemic Properties", cex = 1.25, line = 0.5)
text(26.5, 62, labels = expression(paste("Day of peak prevalence")), xpd = NA, srt = 270, cex = 1.5)
points(st.md.list ~ st.ee.tmax.C, pch = 21, bg = c("purple3", "dodgerblue", "limegreen", "chocolate2", "red3"), cex = 1.75)
text(23.75, 56, labels = "Epi. size", cex = 1.25)
text(21.5, 69, labels = "Day of P.P.", cex = 1.25)
legend("topleft", legend = "C", bty = "n", cex = 1.5, adj = c(0.9, 0.2))

par(mfrow = c(1, 3))
# D) Temps for Cooling Date
plot(cd.list[[5]]$Temp-273.15 ~ cd.list[[1]]$time, type = "l", main = "", xlab = "", ylab = expression(paste("Temperature (",degree,"C)")), 
     col = "red3", xlim = c(0, 150), ylim = c(14, 26.5), lwd=2, cex.axis = 1.25, cex.lab = 1.5)
points(cd.list[[4]]$Temp-273.15 ~ cd.list[[1]]$time, type = "l", col = "chocolate2", lwd=2, lty = 5)
points(cd.list[[3]]$Temp-273.15 ~ cd.list[[1]]$time, type = "l", col = "limegreen", lwd=2, lty = 2)
points(cd.list[[2]]$Temp-273.15 ~ cd.list[[1]]$time, type = "l", col = "dodgerblue", lwd=2, lty = 4)
points(cd.list[[1]]$Temp-273.15 ~ cd.list[[1]]$time, type = "l", col = "purple3", lwd=2, lty = 3)
text(x = 115, y = 24, labels = "Day", cex = 2)
legend("topleft", legend = "D", bty = "n", cex = 1.5, adj = c(0.9, 0))

text(x = 30, y = 20.2, labels = expression(paste(italic(D)," =")), cex = 1.25)
legend(x = 7, y = 20, legend= c("100", "90", "80", "70", "60"), lty = c(1, 5, 2, 4, 3), pch = NA, bty = "n", cex = 1.25, lwd = 2, col = c("red3", "chocolate2", "limegreen", "dodgerblue", "purple3"))
legend(x = 7, y = 20, legend= c("", "", "", "", ""), lty = c(0, 0, 0, 0, 0), pch = 21, pt.bg = c("red3", "chocolate2", "limegreen", "dodgerblue", "purple3"), bty = "n", cex = 1.25, pt.cex = 1.75)

# E) Epidemics for Cooling Date
plot(cd.list[[5]]$Prev ~ cd.list[[1]]$time, type = "l", main = "", xlab = "", ylab = "Infection prevalence", 
     col = "red3", xlim = c(0, 150), ylim = c(0, 0.6), lwd=2, cex.lab = 1.5, cex.axis = 1.25, lty = 1)
lines(cd.list[[4]]$Prev ~ cd.list[[1]]$time, col = "chocolate2", lty = 5, lwd=2)
lines(cd.list[[3]]$Prev ~ cd.list[[1]]$time, col = "limegreen", lty = 2, lwd=2)
lines(cd.list[[2]]$Prev ~ cd.list[[1]]$time, col = "dodgerblue", lty = 4, lwd=2)
lines(cd.list[[1]]$Prev ~ cd.list[[1]]$time, col = "purple3", lty = 3, lwd=2)
legend("topleft", legend = "E", bty = "n", cex = 1.5, adj = c(0.9, 0.2))

# F) Parameter plot for Cooling Date
plot(cd.episize ~ cd.seq, type = "l", main = "", xlab = expression(paste("Parameter ",italic(D))), ylab = expression(paste("Epidemic size  (prevalence days)")), 
     col = "black", xlim = c(60, 100), ylim = c(0, 51), lwd=2, cex.axis = 1.25, cex.lab = 1.5)
points(cd.es.list ~ cd.ee.seq, pch = 21, bg = c("purple3", "dodgerblue", "limegreen", "chocolate2", "red3"), cex = 1.75)
par(new = TRUE)
plot(cd.maxdate ~ cd.seq, type = "l", lwd = 2, col = "darkgrey",  ylim = c(55, 73), axes = FALSE, bty = "n",
     ylab = "", xlab ="", lty = 1)
axis(side = 4, cex.axis = 1.25)
text(110, 64, labels = expression(paste("Day of peak prevalence")), xpd = NA, srt = 270, cex = 1.5)
points(cd.md.list ~ cd.ee.seq, pch = 21, bg = c("purple3", "dodgerblue", "limegreen", "chocolate2", "red3"), cex = 1.75)
text(72, 70, labels = "Epi. size", cex = 1.25)
text(74, 57, labels = "Day of P.P.", cex = 1.25)
legend("topleft", legend = "F", bty = "n", cex = 1.5, adj = c(0.9, 0.2))

par(mfrow = c(1, 3))
# G) Temps for model 3 (Cooling rates)
plot(cr.list[[5]]$Temp-273.15 ~ cr.list[[1]]$time, type = "l", main = "", xlab = "", ylab = expression(paste("Temperature (",degree,"C)")), 
     col = "red3", xlim = c(0, 150), ylim = c(14, 26.5), lwd=2, cex.axis = 1.25, cex.lab = 1.5)
points(cr.list[[4]]$Temp-273.15 ~ cr.list[[1]]$time, type = "l", col = "chocolate2", lwd=2, lty = 5)
points(cr.list[[3]]$Temp-273.15 ~ cr.list[[1]]$time, type = "l", col = "limegreen", lwd=2, lty = 2)
points(cr.list[[2]]$Temp-273.15 ~ cr.list[[1]]$time, type = "l", col = "dodgerblue", lwd=2, lty = 4)
points(cr.list[[1]]$Temp-273.15 ~ cr.list[[1]]$time, type = "l", col = "purple3", lwd=2, lty = 3)
text(x = 110, y = 24, labels = "Rate", cex = 2)
legend("topleft", legend = "G", bty = "n", cex = 1.5, adj = c(0.9, 0.2))
mtext(text = "Time (days)", side = 1, line = 3, cex = 1.05)

# H) Epidemics for model 3 (Cooling rates)
plot(cr.list[[5]]$Prev ~ cr.list[[1]]$time, type = "l", main = "", xlab = "", ylab = "Infection prevalence", 
     col = "red3", xlim = c(0, 150), ylim = c(0, 0.6), lwd=2, cex.lab = 1.5, cex.axis = 1.25, lty = 1)
lines(cr.list[[4]]$Prev ~ cr.list[[1]]$time, col = "chocolate2", lty = 5, lwd=2)
lines(cr.list[[3]]$Prev ~ cr.list[[1]]$time, col = "limegreen", lty = 2, lwd=2)
lines(cr.list[[2]]$Prev ~ cr.list[[1]]$time, col = "dodgerblue", lty = 4, lwd=2)
lines(cr.list[[1]]$Prev ~ cr.list[[1]]$time, col = "purple", lty = 3, lwd=2)
legend("topleft", legend = "H", bty = "n", cex = 1.5, adj = c(0.9, 0.2))
mtext(text = "Time (days)", side = 1, line = 3, cex = 1.05)

text(x = 110, y = .58, labels = expression(paste(italic(R)," =")), cex = 1.25)
legend(x = 90, y = .57, legend= c("1.18", "1.13", "1.09", "1.06", "1.04"), lty = c(1, 5, 2, 4, 3), pch = NA, bty = "n", cex = 1.25, lwd = 2, col = c("red3", "chocolate2", "limegreen", "dodgerblue", "purple3"))
legend(x = 100, y = .57, legend= c("", "", "", "", ""), lty = c(0, 0, 0, 0, 0), pch = 21, pt.bg = c("red3", "chocolate2", "limegreen", "dodgerblue", "purple3"), bty = "n", cex = 1.25, pt.cex = 1.75)

# I) Parameter plot for Cooling Rate
plot(cr.episize ~ cr.seq, type = "l", main = "", xlab = "", ylab = expression(paste("Epidemic size (prevalence days)")), 
     col = "black", xlim = c(1.04, 1.18), ylim = c(0, 51), lwd=2, cex.axis = 1.25, cex.lab = 1.5)
points(cr.es.list ~ cr.ee.seq, pch = 21, bg = c("purple3", "dodgerblue", "limegreen", "chocolate2", "red3"), cex = 1.75)
par(new = TRUE)
plot(cr.maxdate ~ cr.seq, type = "l", lwd = 2, col = "darkgrey",  ylim = c(55, 73), axes = FALSE, bty = "n",
     ylab = "", xlab ="", lty = 1)
axis(side = 4, cex.axis = 1.25)
text(1.215, 64, labels = expression(paste("Day of peak prevalence")), xpd = NA, srt = 270, cex = 1.5)
points(cr.md.list ~ cr.ee.seq, pch = 21, bg = c("purple3", "dodgerblue", "limegreen", "chocolate2", "red3"), cex = 1.75)
text(1.13, 68, labels = "Epi. size", cex = 1.25)
text(1.13, 57, labels = "Day of P.P.", cex = 1.25)
legend("topleft", legend = "I", bty = "n", cex = 1.5, adj = c(0.9, 0.2))
mtext(text = "Parameter value", side = 1, line = 3, cex = 1.05)